# knn-graph function written in C++

The function `knn_graph.cpp` was written by Thomas Neumann and adapted by Maren Büttner for graph-LISI.
Manual compilation:

```
g++ -std=c++11 -O3 knn_graph.cpp -o knn_graph.o
```

A more modern version with `C++17` features is planned.
